@@ -6,6 +6,7 @@ import os
 import re
 import stat
 import zc.buildout
+from infi.execute import execute_async
 
 import collective.recipe.template
 
@@ -29,7 +30,7 @@ class Recipe(collective.recipe.template.Recipe):
 
     @classmethod
     def extract_version_tag(cls):
-        from git import LocalRepository
+        from gitpy import LocalRepository
         from os import curdir, path
         repository = LocalRepository(curdir)
         branch = repository.getCurrentBranch()
@@ -38,18 +39,40 @@ class Recipe(collective.recipe.template.Recipe):
             return cls.get_commit_describe(head)
         current_branch = branch.name
         stripped_branch = current_branch.split('/')[0]
-        return cls.get_commit_describe(head)
+        if current_branch.startswith('release/') or current_branch.startswith('support/') or \
+                                                    current_branch.startswith('hotfix/'):
+            return cls.get_commit_describe(head)
+        if 'master' in stripped_branch:
+            return cls.get_commit_describe(head)
+        else:
+            try:
+                return cls.get_commit_describe(head, 'v*%s*' % stripped_branch)
+            except:
+                pass
+            return  cls.get_commit_describe(head)
+        pass
 
     @classmethod
     def update_buildout_data(cls, buildout):
-        import git
+        import gitpy
         from os import curdir
-        repository = git.LocalRepository(curdir)
+        repository = gitpy.LocalRepository(curdir)
         branch = repository.getCurrentBranch()
+        remote = branch.getRemoteBranch() if branch is not None else None
         head = repository.getHead()
         from zc.buildout.buildout import Options
         data = {}
         data['version'] = cls.extract_version_tag().lstrip('v')
         data['author'] = head.getAuthorName()
         data['author_email'] = head.getAuthorEmail()
+        data['git_local_branch'] = repr(branch.name if branch is not None else '(Not currently on any branch)')
+        data['git_remote_tracking_branch'] = repr(remote.getNormalizedName() if remote is not None else '(No remote tracking)')
+        data['git_remote_url'] = repr(remote.remote.url if remote is not None else '(Not remote tracking)')
+        data['head_subject'] = repr(head.getSubject())
+        data['head_message'] = repr(head.getMessageBody())
+        data['head_hash'] = repr(head.hash)
+        diff = execute_async("git diff --patch --no-color", shell=True)
+        diff.wait()
+        data['dirty_diff'] = repr(diff.get_stdout().replace('${', '$\\{'))
         buildout._data.update({SECTION_NAME: Options(buildout, SECTION_NAME, data)})
+
